<?php

namespace Drupal\msqrole;

/**
 * Interface RoleManagerInterface
 *
 * @package Drupal\msqrole
 */
interface RoleManagerInterface {

  /**
   * Tags to invalidate when masquerading as different role.
   *
   * @const string[]
   */
  const tagsToInvalidate = [
    'config:block.block.bartik_local_actions',
    'config:block.block.bartik_local_tasks',
    'config:system.menu.account',
    'config:system.menu.admin',
    'config:system.menu.tools',
    'local_task',
  ];

  /**
   * Checks whether permission is in given roles.
   *
   * @param $permission
   * @param array $roles
   *
   * @return mixed
   */
  public function isPermissionInRoles($permission, array $roles);

  /**
   * Returns all existing roles
   *
   * @return array
   */
  public function getAllRoles();

  /**
   * Returns the role the current user is masquerading as.
   *
   * @return array
   */
  public function getRoles($uid);

  /**
   * Sets roles in user data.
   *
   * @param mixed $uid
   * @param array $roles
   *
   * @return mixed
   */
  public function setRoles($uid, array $roles);

  /**
   * Whether the current user is masquerading.
   *
   * @return bool
   */
  public function isActive($uid);

  /**
   * Sets active state in user data.
   *
   * @param mixed $uid
   * @param bool  $active
   *
   * @return mixed
   */
  public function setActive($uid, bool $active);

  /**
   * Returns user data from config
   *
   * @param mixed  $uid
   * @param string $key
   *
   * @return null|array|mixed
   */
  public function getData($uid, string $key);

  /**
   * @param mixed  $uid
   * @param string $key
   * @param mixed  $value
   *
   * @return mixed
   */
  public function setData($uid, string $key, $value);

  /**
   * Removes user data
   *
   * @param mixed  $uid
   * @param string $key
   *
   * @return mixed
   */
  public function removeData($uid, string $key);

  /**
   * Resets cache for given user id.
   *
   * @param $uid
   *
   * @return mixed
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function invalidateTags($uid);

}
